aboutsummaryrefslogtreecommitdiffstats
path: root/libtests/qutil.cc
diff options
context:
space:
mode:
Diffstat (limited to 'libtests/qutil.cc')
-rw-r--r--libtests/qutil.cc13
1 files changed, 11 insertions, 2 deletions
diff --git a/libtests/qutil.cc b/libtests/qutil.cc
index a74ae4fe..dcea9fd6 100644
--- a/libtests/qutil.cc
+++ b/libtests/qutil.cc
@@ -150,7 +150,7 @@ void string_conversion_test()
std::cout << "compare failed" << std::endl;
}
delete [] tmp;
// Also test with make_shared_cstr
auto tmp2 = QUtil::make_shared_cstr(embedded_null);
if (memcmp(tmp2.get(), embedded_null.c_str(), 7) == 0)
{
@@ -160,6 +160,15 @@ void string_conversion_test()
{
std::cout << "compare failed" << std::endl;
}
+ auto tmp3 = QUtil::make_unique_cstr(embedded_null);
+ if (memcmp(tmp3.get(), embedded_null.c_str(), 7) == 0)
+ {
+ std::cout << "compare okay" << std::endl;
+ }
+ else
+ {
+ std::cout << "compare failed" << std::endl;
+ }
std::string int_max_str = QUtil::int_to_string(INT_MAX);
std::string int_min_str = QUtil::int_to_string(INT_MIN);
@@ -417,7 +426,7 @@ void transcoding_test()
void print_whoami(char const* str)
{
- auto dup = QUtil::make_shared_cstr(str);
+ auto dup = QUtil::make_unique_cstr(str);
std::cout << QUtil::getWhoami(dup.get()) << std::endl;
}
@@ -150,7 +150,7 @@ void string_conversion_test()
}
delete [] tmp;
- // Also test with make_shared_cstr
+ // Also test with make_shared_cstr and make_unique_cstr
auto tmp2 = QUtil::make_shared_cstr(embedded_null);
if (memcmp(tmp2.get(), embedded_null.c_str(), 7) == 0)